@@ -15,9 +15,12 @@ var searchData=
   ['libinput_5fconfig_5fclick_5fmethod_5fbutton_5fareas',['LIBINPUT_CONFIG_CLICK_METHOD_BUTTON_AREAS',['../group__config.html#gga3e5dc19a83752430d5e8be7fb2020663ab8ce100b5396698712579447b6d2e173',1,'libinput.h']]],
   ['libinput_5fconfig_5fclick_5fmethod_5fclickfinger',['LIBINPUT_CONFIG_CLICK_METHOD_CLICKFINGER',['../group__config.html#gga3e5dc19a83752430d5e8be7fb2020663af81af7bdec6f0f797abf6d68f294d276',1,'libinput.h']]],
   ['libinput_5fconfig_5fclick_5fmethod_5fnone',['LIBINPUT_CONFIG_CLICK_METHOD_NONE',['../group__config.html#gga3e5dc19a83752430d5e8be7fb2020663a44f53f91f3b24a6d41ae9b04420ab374',1,'libinput.h']]],
+  ['libinput_5fconfig_5fdrag_5fdisabled',['LIBINPUT_CONFIG_DRAG_DISABLED',['../group__config.html#ggaddca1d98dbf1b53fc93de3d323588423a8c01d046cb2229408b969a25207f7878',1,'libinput.h']]],
+  ['libinput_5fconfig_5fdrag_5fenabled',['LIBINPUT_CONFIG_DRAG_ENABLED',['../group__config.html#ggaddca1d98dbf1b53fc93de3d323588423a1ab4787df6f5f16b681ca5d741b0f87f',1,'libinput.h']]],
   ['libinput_5fconfig_5fdrag_5flock_5fdisabled',['LIBINPUT_CONFIG_DRAG_LOCK_DISABLED',['../group__config.html#ggaedaabeb8e33f58a032c2e099b91f4579aeecd18dcf22efe84126b0374a9e377f9',1,'libinput.h']]],
   ['libinput_5fconfig_5fdrag_5flock_5fenabled',['LIBINPUT_CONFIG_DRAG_LOCK_ENABLED',['../group__config.html#ggaedaabeb8e33f58a032c2e099b91f4579a5f2fe7ed93c6aa7cd4a8edec35a7d790',1,'libinput.h']]],
   ['libinput_5fconfig_5fdrag_5flock_5fstate',['libinput_config_drag_lock_state',['../group__config.html#gaedaabeb8e33f58a032c2e099b91f4579',1,'libinput.h']]],
+  ['libinput_5fconfig_5fdrag_5fstate',['libinput_config_drag_state',['../group__config.html#gaddca1d98dbf1b53fc93de3d323588423',1,'libinput.h']]],
   ['libinput_5fconfig_5fdwt_5fdisabled',['LIBINPUT_CONFIG_DWT_DISABLED',['../group__config.html#ggacf6846753a607f830ebbd0d3d181f813aa2bc02fbd8904cd0b69c05db91aa5500',1,'libinput.h']]],
   ['libinput_5fconfig_5fdwt_5fenabled',['LIBINPUT_CONFIG_DWT_ENABLED',['../group__config.html#ggacf6846753a607f830ebbd0d3d181f813ac45dae5f37cade37896b159526e75bf7',1,'libinput.h']]],
   ['libinput_5fconfig_5fdwt_5fstate',['libinput_config_dwt_state',['../group__config.html#gacf6846753a607f830ebbd0d3d181f813',1,'libinput.h']]],
@@ -45,6 +48,7 @@ var searchData=
   ['libinput_5fdevice_5fcap_5fgesture',['LIBINPUT_DEVICE_CAP_GESTURE',['../group__device.html#gga3110cdddce94a1df0b8a3306909c8f15a592711b6976e0dab448a1ad8f412d527',1,'libinput.h']]],
   ['libinput_5fdevice_5fcap_5fkeyboard',['LIBINPUT_DEVICE_CAP_KEYBOARD',['../group__device.html#gga3110cdddce94a1df0b8a3306909c8f15a733315d968cac7bd569b43b71664ae4b',1,'libinput.h']]],
   ['libinput_5fdevice_5fcap_5fpointer',['LIBINPUT_DEVICE_CAP_POINTER',['../group__device.html#gga3110cdddce94a1df0b8a3306909c8f15a6e7c3249a8f0503fce7e0a5effc4d73f',1,'libinput.h']]],
+  ['libinput_5fdevice_5fcap_5ftablet_5ftool',['LIBINPUT_DEVICE_CAP_TABLET_TOOL',['../group__device.html#gga3110cdddce94a1df0b8a3306909c8f15ad3eafb7274a330c5839f00030850db6d',1,'libinput.h']]],
   ['libinput_5fdevice_5fcap_5ftouch',['LIBINPUT_DEVICE_CAP_TOUCH',['../group__device.html#gga3110cdddce94a1df0b8a3306909c8f15aad61f92a8154c9017d4e621c768712aa',1,'libinput.h']]],
   ['libinput_5fdevice_5fcapability',['libinput_device_capability',['../group__device.html#ga3110cdddce94a1df0b8a3306909c8f15',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5faccel_5fget_5fdefault_5fprofile',['libinput_device_config_accel_get_default_profile',['../group__config.html#ga288b904c2c0dcc188e3522291ab997c9',1,'libinput.h']]],
@@ -90,11 +94,14 @@ var searchData=
   ['libinput_5fdevice_5fconfig_5fsend_5fevents_5fget_5fmode',['libinput_device_config_send_events_get_mode',['../group__config.html#gae945f2120764570f0b7c48b69a035543',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5fsend_5fevents_5fget_5fmodes',['libinput_device_config_send_events_get_modes',['../group__config.html#gaa03e5c609b0b199402048fcd2cf85b24',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5fsend_5fevents_5fset_5fmode',['libinput_device_config_send_events_set_mode',['../group__config.html#gaacc79635146b888ddaf1cb35363b22ce',1,'libinput.h']]],
+  ['libinput_5fdevice_5fconfig_5ftap_5fget_5fdefault_5fdrag_5fenabled',['libinput_device_config_tap_get_default_drag_enabled',['../group__config.html#ga1c67925fe57210fc34ee0fa07b8e051a',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5ftap_5fget_5fdefault_5fdrag_5flock_5fenabled',['libinput_device_config_tap_get_default_drag_lock_enabled',['../group__config.html#gaa9ac23a944aa2232397bcd856cc55055',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5ftap_5fget_5fdefault_5fenabled',['libinput_device_config_tap_get_default_enabled',['../group__config.html#gaf6906b7344ee8d446594de08b4d065be',1,'libinput.h']]],
+  ['libinput_5fdevice_5fconfig_5ftap_5fget_5fdrag_5fenabled',['libinput_device_config_tap_get_drag_enabled',['../group__config.html#gab75b1a0a6864c8916b13bfced9acc665',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5ftap_5fget_5fdrag_5flock_5fenabled',['libinput_device_config_tap_get_drag_lock_enabled',['../group__config.html#ga096a8960db3d6e43c419180270755584',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5ftap_5fget_5fenabled',['libinput_device_config_tap_get_enabled',['../group__config.html#ga8bfe1d541dcadaedeedcd7a98d5b7e07',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5ftap_5fget_5ffinger_5fcount',['libinput_device_config_tap_get_finger_count',['../group__config.html#ga13973d6bd75a99708723e3c6684517c1',1,'libinput.h']]],
+  ['libinput_5fdevice_5fconfig_5ftap_5fset_5fdrag_5fenabled',['libinput_device_config_tap_set_drag_enabled',['../group__config.html#gad4416f89e0a709005854826affd014d9',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5ftap_5fset_5fdrag_5flock_5fenabled',['libinput_device_config_tap_set_drag_lock_enabled',['../group__config.html#ga8b72d649a4e05a455c1d0ec4194cb755',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5ftap_5fset_5fenabled',['libinput_device_config_tap_set_enabled',['../group__config.html#ga3caf860883d4e2e42b7842599da03e56',1,'libinput.h']]],
   ['libinput_5fdevice_5fget_5fcontext',['libinput_device_get_context',['../group__device.html#ga90c6868911d8aba103278c9208d5205e',1,'libinput.h']]],
@@ -148,9 +155,10 @@ var searchData=
   ['libinput_5fevent_5fget_5fcontext',['libinput_event_get_context',['../group__event.html#ga28557ae0295f61c45f9b6e4ff7f86632',1,'libinput.h']]],
   ['libinput_5fevent_5fget_5fdevice',['libinput_event_get_device',['../group__event.html#ga8a49a089181960f7536344f7637ea777',1,'libinput.h']]],
   ['libinput_5fevent_5fget_5fdevice_5fnotify_5fevent',['libinput_event_get_device_notify_event',['../group__event.html#ga2bbc1391a3397d57d37ae3e2f8175abc',1,'libinput.h']]],
-  ['libinput_5fevent_5fget_5fgesture_5fevent',['libinput_event_get_gesture_event',['../group__event.html#gae173f30b70c265036bbdc9557f3115c4',1,'libinput.h']]],
+  ['libinput_5fevent_5fget_5fgesture_5fevent',['libinput_event_get_gesture_event',['../libinput_8h.html#ae173f30b70c265036bbdc9557f3115c4',1,'libinput.h']]],
   ['libinput_5fevent_5fget_5fkeyboard_5fevent',['libinput_event_get_keyboard_event',['../group__event.html#ga8378f8fdd01e8afbcea8ddbb5411570d',1,'libinput.h']]],
   ['libinput_5fevent_5fget_5fpointer_5fevent',['libinput_event_get_pointer_event',['../group__event.html#ga52acdc3afcf75efeb8153f50eef20615',1,'libinput.h']]],
+  ['libinput_5fevent_5fget_5ftablet_5ftool_5fevent',['libinput_event_get_tablet_tool_event',['../group__event.html#gadfd7d9f1c3210f394faa60928f3c187f',1,'libinput.h']]],
   ['libinput_5fevent_5fget_5ftouch_5fevent',['libinput_event_get_touch_event',['../group__event.html#gad2cba8252024bdcc341499bedd3d0be7',1,'libinput.h']]],
   ['libinput_5fevent_5fget_5ftype',['libinput_event_get_type',['../group__event.html#ga430a3a7369afd6c5ff722179327df79a',1,'libinput.h']]],
   ['libinput_5fevent_5fkeyboard',['libinput_event_keyboard',['../structlibinput__event__keyboard.html',1,'']]],
@@ -185,6 +193,43 @@ var searchData=
   ['libinput_5fevent_5fpointer_5fhas_5faxis',['libinput_event_pointer_has_axis',['../group__event__pointer.html#ga1fdd37a49eae958aaf78a0596cd5cef5',1,'libinput.h']]],
   ['libinput_5fevent_5fpointer_5fmotion',['LIBINPUT_EVENT_POINTER_MOTION',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7ca1812725b7fac7f096cb5d667a6bf89e9',1,'libinput.h']]],
   ['libinput_5fevent_5fpointer_5fmotion_5fabsolute',['LIBINPUT_EVENT_POINTER_MOTION_ABSOLUTE',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7ca5e277107f22df970e882ef76dd6cc315',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool',['libinput_event_tablet_tool',['../structlibinput__event__tablet__tool.html',1,'']]],
+  ['libinput_5fevent_5ftablet_5ftool_5faxis',['LIBINPUT_EVENT_TABLET_TOOL_AXIS',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7cafd96baa20189125ce908b3d65a845de1',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fbutton',['LIBINPUT_EVENT_TABLET_TOOL_BUTTON',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7ca72cb2d7532fb3116debc00d7eecebfa9',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fdistance_5fhas_5fchanged',['libinput_event_tablet_tool_distance_has_changed',['../group__event__tablet.html#ga161c5a254417ed5527beadcdf1bdc55c',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5fbase_5fevent',['libinput_event_tablet_tool_get_base_event',['../group__event__tablet.html#ga90299b56480264cf775c871e52526bb9',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5fbutton',['libinput_event_tablet_tool_get_button',['../group__event__tablet.html#gae36ab2ab73d8b7f00da4cc33f22699ef',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5fbutton_5fstate',['libinput_event_tablet_tool_get_button_state',['../group__event__tablet.html#ga143f62808583b7dddf0a8aa259f71cdb',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5fdistance',['libinput_event_tablet_tool_get_distance',['../group__event__tablet.html#gaae6c3a527a872ef1041d35b0713ed893',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5fdx',['libinput_event_tablet_tool_get_dx',['../group__event__tablet.html#ga868763e264a48cb8df72f5b4724a3c4e',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5fdy',['libinput_event_tablet_tool_get_dy',['../group__event__tablet.html#ga72feb15de8ee3c34a3fa23a78a5c1f3e',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5fpressure',['libinput_event_tablet_tool_get_pressure',['../group__event__tablet.html#gad13f3feea6b9bf599e10e14e96bb9f0b',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5fproximity_5fstate',['libinput_event_tablet_tool_get_proximity_state',['../group__event__tablet.html#ga07823afb37a198173478e029e45ab3ef',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5frotation',['libinput_event_tablet_tool_get_rotation',['../group__event__tablet.html#gae9f1fc19b403e876efd2bd3c3e0b37d6',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5fseat_5fbutton_5fcount',['libinput_event_tablet_tool_get_seat_button_count',['../group__event__tablet.html#ga9dc041db687b59a68e932d0c440af168',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5fslider_5fposition',['libinput_event_tablet_tool_get_slider_position',['../group__event__tablet.html#ga3511bef68bd74deb28f50547f84b0b4d',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5ftilt_5fx',['libinput_event_tablet_tool_get_tilt_x',['../group__event__tablet.html#ga254bf5731441eece5c504c1c95a542c4',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5ftilt_5fy',['libinput_event_tablet_tool_get_tilt_y',['../group__event__tablet.html#ga622aa372b227da77ebb131b183bce9a3',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5ftime',['libinput_event_tablet_tool_get_time',['../group__event__tablet.html#gab35442e0f19101ef200f72c044ab5bbd',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5ftime_5fusec',['libinput_event_tablet_tool_get_time_usec',['../group__event__tablet.html#ga76305fb7651050e33f1bbbc49ec5fb14',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5ftip_5fstate',['libinput_event_tablet_tool_get_tip_state',['../group__event__tablet.html#ga471f9f86ea1de40f036a1ad38bd8dd3a',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5ftool',['libinput_event_tablet_tool_get_tool',['../group__event__tablet.html#gacb4fc9dfc2b370c81f557e6c6f64093a',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5fwheel_5fdelta',['libinput_event_tablet_tool_get_wheel_delta',['../group__event__tablet.html#ga05719a8cb6d74c2f84b7fbfae6036567',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5fwheel_5fdelta_5fdiscrete',['libinput_event_tablet_tool_get_wheel_delta_discrete',['../group__event__tablet.html#gac983a446dab6d1d6835273f2b6110595',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5fx',['libinput_event_tablet_tool_get_x',['../group__event__tablet.html#gab392d487dd9758677066ef8156e7d18c',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5fx_5ftransformed',['libinput_event_tablet_tool_get_x_transformed',['../group__event__tablet.html#ga3b128b24b9fe19a98cb0aaf3624c5ab7',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5fy',['libinput_event_tablet_tool_get_y',['../group__event__tablet.html#gab306166e50d78ece22a1241ba59dfdbc',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5fy_5ftransformed',['libinput_event_tablet_tool_get_y_transformed',['../group__event__tablet.html#ga6c19f3b3679c24f26a46192066f64805',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fpressure_5fhas_5fchanged',['libinput_event_tablet_tool_pressure_has_changed',['../group__event__tablet.html#ga2df1f82b47f641d099f9ccaedfb9240f',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fproximity',['LIBINPUT_EVENT_TABLET_TOOL_PROXIMITY',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7ca4f726f7db59c83dd948a5ea1d59f57b8',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5frotation_5fhas_5fchanged',['libinput_event_tablet_tool_rotation_has_changed',['../group__event__tablet.html#gad20359ff7caf5869fc00a57fda81a2a7',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fslider_5fhas_5fchanged',['libinput_event_tablet_tool_slider_has_changed',['../group__event__tablet.html#ga50f7af0691ce2196b29ce7715136a2c4',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5ftilt_5fx_5fhas_5fchanged',['libinput_event_tablet_tool_tilt_x_has_changed',['../group__event__tablet.html#gaa640fef5f4211829e3afa9ff60f935a1',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5ftilt_5fy_5fhas_5fchanged',['libinput_event_tablet_tool_tilt_y_has_changed',['../group__event__tablet.html#gaa16d257e4cee353883d39023c0707034',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5ftip',['LIBINPUT_EVENT_TABLET_TOOL_TIP',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7ca97e12980dafac44aa6b4501e1a6c9a7a',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fwheel_5fhas_5fchanged',['libinput_event_tablet_tool_wheel_has_changed',['../group__event__tablet.html#gaba85fea05184c0d727ed8eb415e17c3f',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fx_5fhas_5fchanged',['libinput_event_tablet_tool_x_has_changed',['../group__event__tablet.html#ga5ccadabe7f75a0639306481ff402058f',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fy_5fhas_5fchanged',['libinput_event_tablet_tool_y_has_changed',['../group__event__tablet.html#ga2bbe55e25c7ba2865a958f83175ee877',1,'libinput.h']]],
   ['libinput_5fevent_5ftouch',['libinput_event_touch',['../structlibinput__event__touch.html',1,'']]],
   ['libinput_5fevent_5ftouch_5fcancel',['LIBINPUT_EVENT_TOUCH_CANCEL',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7caaf4ed8adce078146aedac569e3178052',1,'libinput.h']]],
   ['libinput_5fevent_5ftouch_5fdown',['LIBINPUT_EVENT_TOUCH_DOWN',['../group__base.html#ggac30276a06e8b1434b959f2c8dde74f7caa14993972db3e944b4e3f5e74dd99dcb',1,'libinput.h']]],
@@ -243,6 +288,36 @@ var searchData=
   ['libinput_5fseat_5funref',['libinput_seat_unref',['../group__seat.html#ga81d52d0e9332f07c39a899c8c2fd3400',1,'libinput.h']]],
   ['libinput_5fset_5fuser_5fdata',['libinput_set_user_data',['../group__base.html#gac1a020ab0a0da92749e24e80538ab28f',1,'libinput.h']]],
   ['libinput_5fsuspend',['libinput_suspend',['../group__base.html#ga60662dc666f6188dc207467c9d8e99ab',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool',['libinput_tablet_tool',['../structlibinput__tablet__tool.html',1,'']]],
+  ['libinput_5ftablet_5ftool_5fget_5fserial',['libinput_tablet_tool_get_serial',['../group__event__tablet.html#gac8084f1e2891ccaa9be5faedf4310f78',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5fget_5ftool_5fid',['libinput_tablet_tool_get_tool_id',['../group__event__tablet.html#ga5ba26a193ce809fab9234b2253bcfff8',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5fget_5ftype',['libinput_tablet_tool_get_type',['../group__event__tablet.html#ga879d814a10261d8f379dc26d2789bfa8',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5fget_5fuser_5fdata',['libinput_tablet_tool_get_user_data',['../group__event__tablet.html#gad5e4615494fe6a18d36d7819f4101a9e',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5fhas_5fbutton',['libinput_tablet_tool_has_button',['../group__event__tablet.html#gac6caf390be962bbe330e30d61cc24a82',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5fhas_5fdistance',['libinput_tablet_tool_has_distance',['../group__event__tablet.html#ga6e20b30e6e6cbddbf2cc159b5d6b7046',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5fhas_5fpressure',['libinput_tablet_tool_has_pressure',['../group__event__tablet.html#gaa4fa6ae9a0c4f9212a28dbd50ee54af3',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5fhas_5frotation',['libinput_tablet_tool_has_rotation',['../group__event__tablet.html#gaab7bcd835ac261f8baace7a1f2f3b26d',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5fhas_5fslider',['libinput_tablet_tool_has_slider',['../group__event__tablet.html#gae004c5b3a2553ea58673871f69d46a36',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5fhas_5ftilt',['libinput_tablet_tool_has_tilt',['../group__event__tablet.html#gac5470ae95d36cc733f5a9167c087f8d1',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5fhas_5fwheel',['libinput_tablet_tool_has_wheel',['../group__event__tablet.html#gaca9317e6ba30236004b183922270cf67',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5fis_5funique',['libinput_tablet_tool_is_unique',['../group__event__tablet.html#ga22aff11d12f9f4541cc2a8152da62207',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5fproximity_5fstate',['libinput_tablet_tool_proximity_state',['../group__device.html#ga54f9b346c0338de742583a8e7c2b0628',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5fproximity_5fstate_5fin',['LIBINPUT_TABLET_TOOL_PROXIMITY_STATE_IN',['../group__device.html#gga54f9b346c0338de742583a8e7c2b0628a90e9036c5474e8d5675549ceadcbd5f2',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5fproximity_5fstate_5fout',['LIBINPUT_TABLET_TOOL_PROXIMITY_STATE_OUT',['../group__device.html#gga54f9b346c0338de742583a8e7c2b0628aca836e7d6fb61219ba4627ccaf0b47f8',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5fref',['libinput_tablet_tool_ref',['../group__event__tablet.html#ga3590fb3c4c03fcfbd2171e6f012a755d',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5fset_5fuser_5fdata',['libinput_tablet_tool_set_user_data',['../group__event__tablet.html#gac875c430f43dbf53c10c6884e2808338',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5ftip_5fdown',['LIBINPUT_TABLET_TOOL_TIP_DOWN',['../group__device.html#ggabc8383829ae67efea5543fb8af117091a5d3293f81d157a683b614ba98605a419',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5ftip_5fstate',['libinput_tablet_tool_tip_state',['../group__device.html#gabc8383829ae67efea5543fb8af117091',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5ftip_5fup',['LIBINPUT_TABLET_TOOL_TIP_UP',['../group__device.html#ggabc8383829ae67efea5543fb8af117091aeeb7a764816c32a910bbdb14314ba613',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5ftype',['libinput_tablet_tool_type',['../group__device.html#ga8348e628baa2646d31abf0fe7245924f',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5ftype_5fairbrush',['LIBINPUT_TABLET_TOOL_TYPE_AIRBRUSH',['../group__device.html#gga8348e628baa2646d31abf0fe7245924fa34519f7fadd32713f2383e6142016bb3',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5ftype_5fbrush',['LIBINPUT_TABLET_TOOL_TYPE_BRUSH',['../group__device.html#gga8348e628baa2646d31abf0fe7245924fad4a91e99e064f8172bd2ab8310c106d0',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5ftype_5feraser',['LIBINPUT_TABLET_TOOL_TYPE_ERASER',['../group__device.html#gga8348e628baa2646d31abf0fe7245924fa69812dd85e9d5b6775ecaf52ece3c19f',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5ftype_5flens',['LIBINPUT_TABLET_TOOL_TYPE_LENS',['../group__device.html#gga8348e628baa2646d31abf0fe7245924fa56a0427909230244aeedad4e48b0384c',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5ftype_5fmouse',['LIBINPUT_TABLET_TOOL_TYPE_MOUSE',['../group__device.html#gga8348e628baa2646d31abf0fe7245924fa2544090800eca843af88bb2cf383e92e',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5ftype_5fpen',['LIBINPUT_TABLET_TOOL_TYPE_PEN',['../group__device.html#gga8348e628baa2646d31abf0fe7245924fa9a76daea205049e4b71b0c30bb203436',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5ftype_5fpencil',['LIBINPUT_TABLET_TOOL_TYPE_PENCIL',['../group__device.html#gga8348e628baa2646d31abf0fe7245924faec53813f855d7009fb1476c4a95990c6',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5funref',['libinput_tablet_tool_unref',['../group__event__tablet.html#ga10577ff3acd02131ceb8cd7d5e4469ee',1,'libinput.h']]],
   ['libinput_5fudev_5fassign_5fseat',['libinput_udev_assign_seat',['../group__base.html#ga71a60660b30cb476495e75766222d144',1,'libinput.h']]],
   ['libinput_5fudev_5fcreate_5fcontext',['libinput_udev_create_context',['../group__base.html#ga7512ea602d4b259085c47f6374b078d1',1,'libinput.h']]],
   ['libinput_5funref',['libinput_unref',['../group__base.html#ga7ed0797d23e34b650e0aeb98b5350309',1,'libinput.h']]],
