@@ -44,11 +44,14 @@ var searchData=
   ['libinput_5fdevice_5fconfig_5fsend_5fevents_5fget_5fmode',['libinput_device_config_send_events_get_mode',['../group__config.html#gae945f2120764570f0b7c48b69a035543',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5fsend_5fevents_5fget_5fmodes',['libinput_device_config_send_events_get_modes',['../group__config.html#gaa03e5c609b0b199402048fcd2cf85b24',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5fsend_5fevents_5fset_5fmode',['libinput_device_config_send_events_set_mode',['../group__config.html#gaacc79635146b888ddaf1cb35363b22ce',1,'libinput.h']]],
+  ['libinput_5fdevice_5fconfig_5ftap_5fget_5fdefault_5fdrag_5fenabled',['libinput_device_config_tap_get_default_drag_enabled',['../group__config.html#ga1c67925fe57210fc34ee0fa07b8e051a',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5ftap_5fget_5fdefault_5fdrag_5flock_5fenabled',['libinput_device_config_tap_get_default_drag_lock_enabled',['../group__config.html#gaa9ac23a944aa2232397bcd856cc55055',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5ftap_5fget_5fdefault_5fenabled',['libinput_device_config_tap_get_default_enabled',['../group__config.html#gaf6906b7344ee8d446594de08b4d065be',1,'libinput.h']]],
+  ['libinput_5fdevice_5fconfig_5ftap_5fget_5fdrag_5fenabled',['libinput_device_config_tap_get_drag_enabled',['../group__config.html#gab75b1a0a6864c8916b13bfced9acc665',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5ftap_5fget_5fdrag_5flock_5fenabled',['libinput_device_config_tap_get_drag_lock_enabled',['../group__config.html#ga096a8960db3d6e43c419180270755584',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5ftap_5fget_5fenabled',['libinput_device_config_tap_get_enabled',['../group__config.html#ga8bfe1d541dcadaedeedcd7a98d5b7e07',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5ftap_5fget_5ffinger_5fcount',['libinput_device_config_tap_get_finger_count',['../group__config.html#ga13973d6bd75a99708723e3c6684517c1',1,'libinput.h']]],
+  ['libinput_5fdevice_5fconfig_5ftap_5fset_5fdrag_5fenabled',['libinput_device_config_tap_set_drag_enabled',['../group__config.html#gad4416f89e0a709005854826affd014d9',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5ftap_5fset_5fdrag_5flock_5fenabled',['libinput_device_config_tap_set_drag_lock_enabled',['../group__config.html#ga8b72d649a4e05a455c1d0ec4194cb755',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5ftap_5fset_5fenabled',['libinput_device_config_tap_set_enabled',['../group__config.html#ga3caf860883d4e2e42b7842599da03e56',1,'libinput.h']]],
   ['libinput_5fdevice_5fget_5fcontext',['libinput_device_get_context',['../group__device.html#ga90c6868911d8aba103278c9208d5205e',1,'libinput.h']]],
@@ -91,9 +94,10 @@ var searchData=
   ['libinput_5fevent_5fget_5fcontext',['libinput_event_get_context',['../group__event.html#ga28557ae0295f61c45f9b6e4ff7f86632',1,'libinput.h']]],
   ['libinput_5fevent_5fget_5fdevice',['libinput_event_get_device',['../group__event.html#ga8a49a089181960f7536344f7637ea777',1,'libinput.h']]],
   ['libinput_5fevent_5fget_5fdevice_5fnotify_5fevent',['libinput_event_get_device_notify_event',['../group__event.html#ga2bbc1391a3397d57d37ae3e2f8175abc',1,'libinput.h']]],
-  ['libinput_5fevent_5fget_5fgesture_5fevent',['libinput_event_get_gesture_event',['../group__event.html#gae173f30b70c265036bbdc9557f3115c4',1,'libinput.h']]],
+  ['libinput_5fevent_5fget_5fgesture_5fevent',['libinput_event_get_gesture_event',['../libinput_8h.html#ae173f30b70c265036bbdc9557f3115c4',1,'libinput.h']]],
   ['libinput_5fevent_5fget_5fkeyboard_5fevent',['libinput_event_get_keyboard_event',['../group__event.html#ga8378f8fdd01e8afbcea8ddbb5411570d',1,'libinput.h']]],
   ['libinput_5fevent_5fget_5fpointer_5fevent',['libinput_event_get_pointer_event',['../group__event.html#ga52acdc3afcf75efeb8153f50eef20615',1,'libinput.h']]],
+  ['libinput_5fevent_5fget_5ftablet_5ftool_5fevent',['libinput_event_get_tablet_tool_event',['../group__event.html#gadfd7d9f1c3210f394faa60928f3c187f',1,'libinput.h']]],
   ['libinput_5fevent_5fget_5ftouch_5fevent',['libinput_event_get_touch_event',['../group__event.html#gad2cba8252024bdcc341499bedd3d0be7',1,'libinput.h']]],
   ['libinput_5fevent_5fget_5ftype',['libinput_event_get_type',['../group__event.html#ga430a3a7369afd6c5ff722179327df79a',1,'libinput.h']]],
   ['libinput_5fevent_5fkeyboard_5fget_5fbase_5fevent',['libinput_event_keyboard_get_base_event',['../group__event__keyboard.html#gae5a3b7e12e7e8b213b3da92a13adb88d',1,'libinput.h']]],
@@ -120,6 +124,38 @@ var searchData=
   ['libinput_5fevent_5fpointer_5fget_5ftime',['libinput_event_pointer_get_time',['../group__event__pointer.html#gac42d0e19d076f4e1fca15f1ec42510d5',1,'libinput.h']]],
   ['libinput_5fevent_5fpointer_5fget_5ftime_5fusec',['libinput_event_pointer_get_time_usec',['../group__event__pointer.html#gaf0997d730299f40dbe3efcfa06c429be',1,'libinput.h']]],
   ['libinput_5fevent_5fpointer_5fhas_5faxis',['libinput_event_pointer_has_axis',['../group__event__pointer.html#ga1fdd37a49eae958aaf78a0596cd5cef5',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fdistance_5fhas_5fchanged',['libinput_event_tablet_tool_distance_has_changed',['../group__event__tablet.html#ga161c5a254417ed5527beadcdf1bdc55c',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5fbase_5fevent',['libinput_event_tablet_tool_get_base_event',['../group__event__tablet.html#ga90299b56480264cf775c871e52526bb9',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5fbutton',['libinput_event_tablet_tool_get_button',['../group__event__tablet.html#gae36ab2ab73d8b7f00da4cc33f22699ef',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5fbutton_5fstate',['libinput_event_tablet_tool_get_button_state',['../group__event__tablet.html#ga143f62808583b7dddf0a8aa259f71cdb',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5fdistance',['libinput_event_tablet_tool_get_distance',['../group__event__tablet.html#gaae6c3a527a872ef1041d35b0713ed893',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5fdx',['libinput_event_tablet_tool_get_dx',['../group__event__tablet.html#ga868763e264a48cb8df72f5b4724a3c4e',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5fdy',['libinput_event_tablet_tool_get_dy',['../group__event__tablet.html#ga72feb15de8ee3c34a3fa23a78a5c1f3e',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5fpressure',['libinput_event_tablet_tool_get_pressure',['../group__event__tablet.html#gad13f3feea6b9bf599e10e14e96bb9f0b',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5fproximity_5fstate',['libinput_event_tablet_tool_get_proximity_state',['../group__event__tablet.html#ga07823afb37a198173478e029e45ab3ef',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5frotation',['libinput_event_tablet_tool_get_rotation',['../group__event__tablet.html#gae9f1fc19b403e876efd2bd3c3e0b37d6',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5fseat_5fbutton_5fcount',['libinput_event_tablet_tool_get_seat_button_count',['../group__event__tablet.html#ga9dc041db687b59a68e932d0c440af168',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5fslider_5fposition',['libinput_event_tablet_tool_get_slider_position',['../group__event__tablet.html#ga3511bef68bd74deb28f50547f84b0b4d',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5ftilt_5fx',['libinput_event_tablet_tool_get_tilt_x',['../group__event__tablet.html#ga254bf5731441eece5c504c1c95a542c4',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5ftilt_5fy',['libinput_event_tablet_tool_get_tilt_y',['../group__event__tablet.html#ga622aa372b227da77ebb131b183bce9a3',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5ftime',['libinput_event_tablet_tool_get_time',['../group__event__tablet.html#gab35442e0f19101ef200f72c044ab5bbd',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5ftime_5fusec',['libinput_event_tablet_tool_get_time_usec',['../group__event__tablet.html#ga76305fb7651050e33f1bbbc49ec5fb14',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5ftip_5fstate',['libinput_event_tablet_tool_get_tip_state',['../group__event__tablet.html#ga471f9f86ea1de40f036a1ad38bd8dd3a',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5ftool',['libinput_event_tablet_tool_get_tool',['../group__event__tablet.html#gacb4fc9dfc2b370c81f557e6c6f64093a',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5fwheel_5fdelta',['libinput_event_tablet_tool_get_wheel_delta',['../group__event__tablet.html#ga05719a8cb6d74c2f84b7fbfae6036567',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5fwheel_5fdelta_5fdiscrete',['libinput_event_tablet_tool_get_wheel_delta_discrete',['../group__event__tablet.html#gac983a446dab6d1d6835273f2b6110595',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5fx',['libinput_event_tablet_tool_get_x',['../group__event__tablet.html#gab392d487dd9758677066ef8156e7d18c',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5fx_5ftransformed',['libinput_event_tablet_tool_get_x_transformed',['../group__event__tablet.html#ga3b128b24b9fe19a98cb0aaf3624c5ab7',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5fy',['libinput_event_tablet_tool_get_y',['../group__event__tablet.html#gab306166e50d78ece22a1241ba59dfdbc',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fget_5fy_5ftransformed',['libinput_event_tablet_tool_get_y_transformed',['../group__event__tablet.html#ga6c19f3b3679c24f26a46192066f64805',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fpressure_5fhas_5fchanged',['libinput_event_tablet_tool_pressure_has_changed',['../group__event__tablet.html#ga2df1f82b47f641d099f9ccaedfb9240f',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5frotation_5fhas_5fchanged',['libinput_event_tablet_tool_rotation_has_changed',['../group__event__tablet.html#gad20359ff7caf5869fc00a57fda81a2a7',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fslider_5fhas_5fchanged',['libinput_event_tablet_tool_slider_has_changed',['../group__event__tablet.html#ga50f7af0691ce2196b29ce7715136a2c4',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5ftilt_5fx_5fhas_5fchanged',['libinput_event_tablet_tool_tilt_x_has_changed',['../group__event__tablet.html#gaa640fef5f4211829e3afa9ff60f935a1',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5ftilt_5fy_5fhas_5fchanged',['libinput_event_tablet_tool_tilt_y_has_changed',['../group__event__tablet.html#gaa16d257e4cee353883d39023c0707034',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fwheel_5fhas_5fchanged',['libinput_event_tablet_tool_wheel_has_changed',['../group__event__tablet.html#gaba85fea05184c0d727ed8eb415e17c3f',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fx_5fhas_5fchanged',['libinput_event_tablet_tool_x_has_changed',['../group__event__tablet.html#ga5ccadabe7f75a0639306481ff402058f',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5ftool_5fy_5fhas_5fchanged',['libinput_event_tablet_tool_y_has_changed',['../group__event__tablet.html#ga2bbe55e25c7ba2865a958f83175ee877',1,'libinput.h']]],
   ['libinput_5fevent_5ftouch_5fget_5fbase_5fevent',['libinput_event_touch_get_base_event',['../group__event__touch.html#gacb2cd144a719c9873cd4621db278e92c',1,'libinput.h']]],
   ['libinput_5fevent_5ftouch_5fget_5fseat_5fslot',['libinput_event_touch_get_seat_slot',['../group__event__touch.html#gabac75c78a0a360995e1a521edb38c4da',1,'libinput.h']]],
   ['libinput_5fevent_5ftouch_5fget_5fslot',['libinput_event_touch_get_slot',['../group__event__touch.html#gaf5294eab86b9125b7fb607049ff9ef09',1,'libinput.h']]],
@@ -149,6 +185,21 @@ var searchData=
   ['libinput_5fseat_5funref',['libinput_seat_unref',['../group__seat.html#ga81d52d0e9332f07c39a899c8c2fd3400',1,'libinput.h']]],
   ['libinput_5fset_5fuser_5fdata',['libinput_set_user_data',['../group__base.html#gac1a020ab0a0da92749e24e80538ab28f',1,'libinput.h']]],
   ['libinput_5fsuspend',['libinput_suspend',['../group__base.html#ga60662dc666f6188dc207467c9d8e99ab',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5fget_5fserial',['libinput_tablet_tool_get_serial',['../group__event__tablet.html#gac8084f1e2891ccaa9be5faedf4310f78',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5fget_5ftool_5fid',['libinput_tablet_tool_get_tool_id',['../group__event__tablet.html#ga5ba26a193ce809fab9234b2253bcfff8',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5fget_5ftype',['libinput_tablet_tool_get_type',['../group__event__tablet.html#ga879d814a10261d8f379dc26d2789bfa8',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5fget_5fuser_5fdata',['libinput_tablet_tool_get_user_data',['../group__event__tablet.html#gad5e4615494fe6a18d36d7819f4101a9e',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5fhas_5fbutton',['libinput_tablet_tool_has_button',['../group__event__tablet.html#gac6caf390be962bbe330e30d61cc24a82',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5fhas_5fdistance',['libinput_tablet_tool_has_distance',['../group__event__tablet.html#ga6e20b30e6e6cbddbf2cc159b5d6b7046',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5fhas_5fpressure',['libinput_tablet_tool_has_pressure',['../group__event__tablet.html#gaa4fa6ae9a0c4f9212a28dbd50ee54af3',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5fhas_5frotation',['libinput_tablet_tool_has_rotation',['../group__event__tablet.html#gaab7bcd835ac261f8baace7a1f2f3b26d',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5fhas_5fslider',['libinput_tablet_tool_has_slider',['../group__event__tablet.html#gae004c5b3a2553ea58673871f69d46a36',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5fhas_5ftilt',['libinput_tablet_tool_has_tilt',['../group__event__tablet.html#gac5470ae95d36cc733f5a9167c087f8d1',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5fhas_5fwheel',['libinput_tablet_tool_has_wheel',['../group__event__tablet.html#gaca9317e6ba30236004b183922270cf67',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5fis_5funique',['libinput_tablet_tool_is_unique',['../group__event__tablet.html#ga22aff11d12f9f4541cc2a8152da62207',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5fref',['libinput_tablet_tool_ref',['../group__event__tablet.html#ga3590fb3c4c03fcfbd2171e6f012a755d',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5fset_5fuser_5fdata',['libinput_tablet_tool_set_user_data',['../group__event__tablet.html#gac875c430f43dbf53c10c6884e2808338',1,'libinput.h']]],
+  ['libinput_5ftablet_5ftool_5funref',['libinput_tablet_tool_unref',['../group__event__tablet.html#ga10577ff3acd02131ceb8cd7d5e4469ee',1,'libinput.h']]],
   ['libinput_5fudev_5fassign_5fseat',['libinput_udev_assign_seat',['../group__base.html#ga71a60660b30cb476495e75766222d144',1,'libinput.h']]],
   ['libinput_5fudev_5fcreate_5fcontext',['libinput_udev_create_context',['../group__base.html#ga7512ea602d4b259085c47f6374b078d1',1,'libinput.h']]],
   ['libinput_5funref',['libinput_unref',['../group__base.html#ga7ed0797d23e34b650e0aeb98b5350309',1,'libinput.h']]]
